.. SEAPY documentation master file, created by
   sphinx-quickstart on Fri Feb  6 11:03:18 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SEAPY's documentation!
=================================

Tools for working with ocean models and data.

SEAPY requires: numpy, scipy, netCDF4, joblib, and numpy_groupies

Contents:

.. toctree::
   :maxdepth: 2

   Module Descriptions <desc>
   modules/index
   Examples <examples>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

